@@ -31,6 +31,8 @@
  * only need to override the members of the class data structure.
  */
 
+#include "config.h"
+
 #include <telepathy-glib/base-connection-manager.h>
 
 #include <string.h>
@@ -531,8 +533,7 @@ tp_base_connection_manager_class_init (TpBaseConnectionManagerClass *klass)
                   G_OBJECT_CLASS_TYPE (klass),
                   G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
                   0,
-                  NULL, NULL,
-                  g_cclosure_marshal_VOID__VOID,
+                  NULL, NULL, NULL,
                   G_TYPE_NONE, 0);
 
   tp_dbus_properties_mixin_class_init (object_class, 0);
