@@ -77,7 +77,7 @@ struct _TpCallChannelPrivate
   GHashTable *state_details;
   TpCallStateReason *state_reason;
   gboolean hardware_streaming;
-  /* TpHandle -> TpCallMemberFlags */
+  /* TpContact -> TpCallMemberFlags */
   GHashTable *members;
   gboolean initial_audio;
   gboolean initial_video;
@@ -270,14 +270,15 @@ _tp_call_members_convert_array (TpConnection *connection,
       TpContact *contact;
 
       /* The contact is supposed to already exists */
-      contact = _tp_connection_lookup_contact (connection, handle);
+      contact = tp_connection_dup_contact_if_possible (connection,
+          handle, NULL);
       if (contact == NULL)
         {
           DEBUG ("No TpContact found for handle %u", handle);
           continue;
         }
 
-      g_ptr_array_add (result, g_object_ref (contact));
+      g_ptr_array_add (result, contact);
     }
 
   return result;
@@ -1046,7 +1047,7 @@ tp_call_channel_class_init (TpCallChannelClass *klass)
 
 
   /**
-   * TpCallChannel::content-added
+   * TpCallChannel::content-added:
    * @self: the #TpCallChannel
    * @content: the newly added #TpCallContent
    *
@@ -1066,7 +1067,7 @@ tp_call_channel_class_init (TpCallChannelClass *klass)
       1, G_TYPE_OBJECT);
 
   /**
-   * TpCallChannel::content-removed
+   * TpCallChannel::content-removed:
    * @self: the #TpCallChannel
    * @content: the newly removed #TpCallContent
    * @reason: a #TpCallStateReason
@@ -1087,7 +1088,7 @@ tp_call_channel_class_init (TpCallChannelClass *klass)
       2, G_TYPE_OBJECT, TP_TYPE_CALL_STATE_REASON);
 
   /**
-   * TpCallChannel::state-changed
+   * TpCallChannel::state-changed:
    * @self: the #TpCallChannel
    * @state: the new #TpCallState
    * @flags: the new #TpCallFlags
@@ -1109,7 +1110,7 @@ tp_call_channel_class_init (TpCallChannelClass *klass)
       G_TYPE_HASH_TABLE);
 
   /**
-   * TpCallChannel::members-changed
+   * TpCallChannel::members-changed:
    * @self: the #TpCallChannel
    * @updates: (type GLib.HashTable) (element-type TelepathyGLib.Contact uint):
    *   #GHashTable mapping #TpContact to its new #TpCallMemberFlags
