@@ -22,6 +22,7 @@
 #ifndef TP_CHANNEL_REQUEST_H
 #define TP_CHANNEL_REQUEST_H
 
+#include <telepathy-glib/account.h>
 #include <telepathy-glib/client-channel-factory.h>
 #include <telepathy-glib/dbus.h>
 #include <telepathy-glib/defs.h>
@@ -72,11 +73,17 @@ TpChannelRequest *tp_channel_request_new (TpDBusDaemon *bus_daemon,
 void tp_channel_request_init_known_interfaces (void);
 
 void tp_channel_request_set_channel_factory (TpChannelRequest *self,
-    TpClientChannelFactory *factory);
+    TpClientChannelFactory *factory) _TP_GNUC_DEPRECATED;
 
 const GHashTable * tp_channel_request_get_immutable_properties (
     TpChannelRequest *self);
 
+TpAccount * tp_channel_request_get_account (TpChannelRequest *self);
+
+gint64 tp_channel_request_get_user_action_time (TpChannelRequest *self);
+
+const gchar * tp_channel_request_get_preferred_handler (TpChannelRequest *self);
+
 const GHashTable * tp_channel_request_get_hints (TpChannelRequest *self);
 
 G_END_DECLS
