@@ -85,17 +85,20 @@ TpChannel *tp_channel_new_from_properties (TpConnection *conn,
 #ifndef TP_DISABLE_DEPRECATED
 gboolean tp_channel_run_until_ready (TpChannel *self, GError **error,
     GMainLoop **loop) _TP_GNUC_DEPRECATED;
-#endif
 
 typedef void (*TpChannelWhenReadyCb) (TpChannel *channel, const GError *error,
     gpointer user_data);
 
 void tp_channel_call_when_ready (TpChannel *self,
-    TpChannelWhenReadyCb callback, gpointer user_data);
+    TpChannelWhenReadyCb callback,
+    gpointer user_data) _TP_GNUC_DEPRECATED_FOR (tp_proxy_prepare_async);
+
+gboolean tp_channel_is_ready (TpChannel *self)
+  _TP_GNUC_DEPRECATED_FOR (tp_proxy_is_ready);
+#endif
 
 void tp_channel_init_known_interfaces (void);
 
-gboolean tp_channel_is_ready (TpChannel *self);
 const gchar *tp_channel_get_channel_type (TpChannel *self);
 GQuark tp_channel_get_channel_type_id (TpChannel *self);
 TpHandle tp_channel_get_handle (TpChannel *self, TpHandleType *handle_type);
