@@ -152,19 +152,21 @@ void tp_connection_set_contact_info_async (TpConnection *self,
 gboolean tp_connection_set_contact_info_finish (TpConnection *self,
     GAsyncResult *result, GError **error);
 
-gboolean tp_connection_is_ready (TpConnection *self);
-
 #ifndef TP_DISABLE_DEPRECATED
+gboolean tp_connection_is_ready (TpConnection *self)
+  _TP_GNUC_DEPRECATED_FOR (tp_proxy_is_prepared);
+
 gboolean tp_connection_run_until_ready (TpConnection *self,
     gboolean connect, GError **error,
     GMainLoop **loop) _TP_GNUC_DEPRECATED;
-#endif
 
 typedef void (*TpConnectionWhenReadyCb) (TpConnection *connection,
     const GError *error, gpointer user_data);
 
 void tp_connection_call_when_ready (TpConnection *self,
-    TpConnectionWhenReadyCb callback, gpointer user_data);
+    TpConnectionWhenReadyCb callback,
+    gpointer user_data) _TP_GNUC_DEPRECATED_FOR (tp_proxy_prepare_async);
+#endif
 
 typedef void (*TpConnectionNameListCb) (const gchar * const *names,
     gsize n, const gchar * const *cms, const gchar * const *protocols,
@@ -292,6 +294,13 @@ gboolean tp_connection_get_balance (TpConnection *self,
     gint *balance, guint *scale, const gchar **currency);
 const gchar * tp_connection_get_balance_uri (TpConnection *self);
 
+void tp_connection_disconnect_async (TpConnection *self,
+    GAsyncReadyCallback callback,
+    gpointer user_data);
+gboolean tp_connection_disconnect_finish (TpConnection *self,
+    GAsyncResult *result,
+    GError **error);
+
 G_END_DECLS
 
 #include <telepathy-glib/_gen/tp-cli-connection.h>
