@@ -18,6 +18,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#include "config.h"
+
 #include "telepathy-glib/contact-search.h"
 
 #include <telepathy-glib/contact-search-result.h>
@@ -472,8 +474,7 @@ tp_contact_search_class_init (TpContactSearchClass *klass)
       G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST,
       0,
-      NULL, NULL,
-      g_cclosure_marshal_VOID__POINTER,
+      NULL, NULL, NULL,
       G_TYPE_NONE,
       1, G_TYPE_POINTER);
 
