@@ -51,6 +51,8 @@
  * Since: 0.7.9
  */
 
+#include "config.h"
+
 #include <telepathy-glib/dbus.h>
 #include <telepathy-glib/dbus-internal.h>
 
@@ -62,6 +64,7 @@
 #include <gobject/gvaluecollector.h>
 
 #include <telepathy-glib/errors.h>
+#include <telepathy-glib/gtypes.h>
 #include <telepathy-glib/util.h>
 
 #define DEBUG_FLAG TP_DEBUG_MISC
@@ -1949,3 +1952,25 @@ tp_asv_dump (GHashTable *asv)
 
   g_debug ("}");
 }
+
+/*
+ * _tp_asv_to_vardict:
+ *
+ * Returns: (transfer full): a #GVariant of type %G_VARIANT_TYPE_VARDICT
+ */
+GVariant *
+_tp_asv_to_vardict (const GHashTable *asv)
+{
+  GValue v = G_VALUE_INIT;
+  GVariant *ret;
+
+  g_value_init (&v, TP_HASH_TYPE_STRING_VARIANT_MAP);
+  g_value_set_boxed (&v, asv);
+
+  ret = dbus_g_value_build_g_variant (&v);
+  g_assert (!tp_strdiff (g_variant_get_type_string (ret), "a{sv}"));
+
+  g_value_unset (&v);
+
+  return g_variant_ref_sink (ret);
+}
