@@ -94,7 +94,7 @@
  * Since: 0.15.5
  */
 
-#include <config.h>
+#include "config.h"
 
 #include "telepathy-glib/file-transfer-channel.h"
 
@@ -110,7 +110,6 @@
 #define DEBUG_FLAG TP_DEBUG_CHANNEL
 #include "telepathy-glib/automatic-client-factory-internal.h"
 #include "telepathy-glib/debug-internal.h"
-#include "_gen/signals-marshal.h"
 
 #include <stdio.h>
 #include <glib.h>
