@@ -32,6 +32,8 @@
  * and #TpStaticHandleRepo for concrete implementations.
  */
 
+#include "config.h"
+
 #include <telepathy-glib/handle-repo.h>
 
 #include <telepathy-glib/handle-repo-internal.h>
@@ -50,8 +52,7 @@ repo_base_init (gpointer klass)
       param_spec = g_param_spec_uint ("handle-type", "Handle type",
           "The TpHandleType held in this handle repository.",
           0, G_MAXUINT32, 0,
-          G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE |
-          G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB | G_PARAM_STATIC_NICK);
+          G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
       g_object_interface_install_property (klass, param_spec);
     }
 }
