@@ -7,6 +7,8 @@
  * notice and this notice are preserved.
  */
 
+#include "config.h"
+
 #include <telepathy-glib/telepathy-glib.h>
 
 #include <telepathy-glib/account-channel-request-internal.h>
@@ -141,9 +143,7 @@ teardown (Test *test,
 
   tp_clear_object (&test->channel);
 
-  tp_cli_connection_run_disconnect (test->connection, -1, &test->error, NULL);
-  g_assert_no_error (test->error);
-
+  tp_tests_connection_assert_disconnect_succeeds (test->connection);
   tp_clear_object (&test->connection);
   tp_clear_object (&test->base_connection);
 
