@@ -1,6 +1,6 @@
 /* A very basic feature test for TpAccount
  *
- * Copyright (C) 2009 Collabora Ltd. <http://www.collabora.co.uk/>
+ * Copyright (C) 2009-2012 Collabora Ltd. <http://www.collabora.co.uk/>
  * Copyright (C) 2009 Nokia Corporation
  *
  * Copying and distribution of this file, with or without modification,
@@ -8,6 +8,8 @@
  * notice and this notice are preserved.
  */
 
+#include "config.h"
+
 #include <telepathy-glib/account.h>
 #include <telepathy-glib/debug.h>
 #include <telepathy-glib/defs.h>
@@ -22,6 +24,7 @@
 #define CONN2_PATH TP_CONN_OBJECT_PATH_BASE "what/ev/s"
 #define CONN1_BUS_NAME TP_CONN_BUS_NAME_BASE "what.ev.er"
 #define CONN2_BUS_NAME TP_CONN_BUS_NAME_BASE "what.ev.s"
+#define SUPERSEDED_PATH TP_ACCOUNT_OBJECT_PATH_BASE "super/seded/whatever"
 
 static void
 test_parse_failure (gconstpointer test_data)
@@ -252,6 +255,59 @@ test_setters (Test *test,
   tp_clear_object (&test->result);
 }
 
+static void
+test_reconnect (Test *test,
+    gconstpointer data)
+{
+  GStrv reconnect_required;
+  const gchar *unset[] = { "unset", NULL };
+
+  test->account = tp_account_new (test->dbus, ACCOUNT_PATH, NULL);
+  g_assert (test->account != NULL);
+
+  if (!tp_strdiff (data, "vardict"))
+    {
+      tp_account_update_parameters_vardict_async (test->account,
+          g_variant_new_parsed ("{ 'set': <%s> }", "value"), unset,
+          tp_tests_result_ready_cb, &test->result);
+      tp_tests_run_until_result (&test->result);
+      tp_account_update_parameters_vardict_finish (test->account, test->result,
+          &reconnect_required, &test->error);
+    }
+  else
+    {
+      GHashTable *set = tp_asv_new (
+          "set", G_TYPE_STRING, "value",
+          NULL);
+
+      tp_account_update_parameters_async (test->account, set, unset,
+          tp_tests_result_ready_cb, &test->result);
+      tp_tests_run_until_result (&test->result);
+      tp_account_update_parameters_finish (test->account, test->result,
+          &reconnect_required, &test->error);
+
+      g_hash_table_unref (set);
+    }
+
+  g_assert_no_error (test->error);
+  /* check that reconnect_required survives longer than result */
+  tp_clear_object (&test->result);
+
+  g_assert (reconnect_required != NULL);
+  g_assert_cmpstr (reconnect_required[0], ==, "set");
+  g_assert_cmpstr (reconnect_required[1], ==, "unset");
+  g_assert_cmpstr (reconnect_required[2], ==, NULL);
+  g_strfreev (reconnect_required);
+
+  tp_account_reconnect_async (test->account, tp_tests_result_ready_cb,
+      &test->result);
+  tp_tests_run_until_result (&test->result);
+  tp_account_reconnect_finish (test->account, test->result, &test->error);
+  g_assert_error (test->error, TP_ERROR, TP_ERROR_NOT_IMPLEMENTED);
+  g_clear_error (&test->error);
+  tp_clear_object (&test->result);
+}
+
 static void
 account_prepare_cb (GObject *source,
     GAsyncResult *result,
@@ -268,31 +324,31 @@ account_prepare_cb (GObject *source,
 
 #define assert_strprop(self, prop, val) \
   {\
-    gchar *s; \
+    gchar *_s; \
     \
     g_object_get (self, \
-        prop, &s, \
+        prop, &_s, \
         NULL); \
-    g_assert_cmpstr (s, ==, val);\
-    g_free (s); \
+    g_assert_cmpstr (_s, ==, val);\
+    g_free (_s); \
   }
 #define assert_uintprop(self, prop, val) \
   {\
-    guint u; \
+    guint _u; \
     \
     g_object_get (self, \
-        prop, &u, \
+        prop, &_u, \
         NULL); \
-    g_assert_cmpuint (u, ==, val);\
+    g_assert_cmpuint (_u, ==, val);\
   }
 #define assert_boolprop(self, prop, val) \
   {\
-    gboolean b; \
+    gboolean _b; \
     \
     g_object_get (self, \
-        prop, &b, \
+        prop, &_b, \
         NULL); \
-    g_assert_cmpint (b, ==, val);\
+    g_assert_cmpint (_b, ==, val);\
   }
 
 static void
@@ -304,6 +360,9 @@ test_prepare_success (Test *test,
   gchar *status = NULL;
   gchar *message = NULL;
   const GHashTable *details = GUINT_TO_POINTER (666);
+  GStrv strv;
+  const gchar * const *cstrv;
+  GVariant *variant;
 
   test->account = tp_account_new (test->dbus, ACCOUNT_PATH, NULL);
   g_assert (test->account != NULL);
@@ -325,6 +384,10 @@ test_prepare_success (Test *test,
   assert_strprop (test->account, "nickname", "badger");
   g_assert_cmpuint (tp_asv_size (tp_account_get_parameters (test->account)),
       ==, 0);
+  variant = tp_account_dup_parameters_vardict (test->account);
+  g_assert_cmpstr (g_variant_get_type_string (variant), ==, "a{sv}");
+  g_assert_cmpuint (g_variant_n_children (variant), ==, 0);
+  g_variant_unref (variant);
   g_assert (!tp_account_get_connect_automatically (test->account));
   assert_boolprop (test->account, "connect-automatically", FALSE);
   g_assert (tp_account_get_has_been_online (test->account));
@@ -414,28 +477,17 @@ test_prepare_success (Test *test,
       "bob.mcbadgers@example.com");
   assert_strprop (test->account, "normalized-name",
       "bob.mcbadgers@example.com");
-}
 
-static void
-get_storage_specific_info_cb (GObject *account,
-    GAsyncResult *result,
-    gpointer user_data)
-{
-  Test *test = user_data;
-  GHashTable *info;
-  GError *error = NULL;
+  g_object_get (test->account,
+      "supersedes", &strv,
+      NULL);
+  g_assert_cmpstr (strv[0], ==, SUPERSEDED_PATH);
+  g_assert_cmpstr (strv[1], ==, NULL);
+  g_strfreev (strv);
 
-  info = tp_account_get_storage_specific_information_finish (
-      TP_ACCOUNT (account), result, &error);
-  g_assert_no_error (error);
-
-  g_assert_cmpuint (g_hash_table_size (info), ==, 3);
-
-  g_assert_cmpint (tp_asv_get_int32 (info, "one", NULL), ==, 1);
-  g_assert_cmpuint (tp_asv_get_uint32 (info, "two", NULL), ==, 2);
-  g_assert_cmpstr (tp_asv_get_string (info, "marco"), ==, "polo");
-
-  g_main_loop_quit (test->mainloop);
+  cstrv = tp_account_get_supersedes (test->account);
+  g_assert_cmpstr (cstrv[0], ==, SUPERSEDED_PATH);
+  g_assert_cmpstr (cstrv[1], ==, NULL);
 }
 
 static void
@@ -444,6 +496,13 @@ test_storage (Test *test,
 {
   GQuark account_features[] = { TP_ACCOUNT_FEATURE_STORAGE, 0 };
   GValue *gvalue;
+  GVariant *gvariant;
+  GHashTable *info;
+  GError *error = NULL;
+  gboolean found;
+  gint32 i;
+  guint32 u;
+  const gchar *s;
 
   test->account = tp_account_new (test->dbus, ACCOUNT_PATH, NULL);
   g_assert (test->account != NULL);
@@ -463,6 +522,11 @@ test_storage (Test *test,
           "storage-identifier", &gvalue,
           NULL);
       g_assert (gvalue == NULL);
+      g_assert (tp_account_get_storage_identifier (test->account) == NULL);
+      g_object_get (test->account,
+          "storage-identifier", &gvariant,
+          NULL);
+      g_assert (gvariant == NULL);
       g_assert_cmpuint (tp_account_get_storage_restrictions (test->account), ==,
           0);
       assert_uintprop (test->account, "storage-restrictions", 0);
@@ -477,6 +541,7 @@ test_storage (Test *test,
       "org.freedesktop.Telepathy.glib.test");
   assert_strprop (test->account, "storage-provider",
       "org.freedesktop.Telepathy.glib.test");
+
   g_assert_cmpstr (
       g_value_get_string (tp_account_get_storage_identifier (test->account)),
       ==, "unique-identifier");
@@ -485,6 +550,20 @@ test_storage (Test *test,
       NULL);
   g_assert_cmpstr (g_value_get_string (gvalue), ==, "unique-identifier");
   g_boxed_free (G_TYPE_VALUE, gvalue);
+
+  gvariant = tp_account_dup_storage_identifier_variant (test->account);
+  g_assert_cmpstr (g_variant_get_type_string (gvariant), ==, "s");
+  g_assert_cmpstr (g_variant_get_string (gvariant, NULL), ==,
+      "unique-identifier");
+  g_variant_unref (gvariant);
+  g_object_get (test->account,
+      "storage-identifier-variant", &gvariant,
+      NULL);
+  g_assert_cmpstr (g_variant_get_type_string (gvariant), ==, "s");
+  g_assert_cmpstr (g_variant_get_string (gvariant, NULL), ==,
+      "unique-identifier");
+  g_variant_unref (gvariant);
+
   g_assert_cmpuint (tp_account_get_storage_restrictions (test->account), ==,
       TP_STORAGE_RESTRICTION_FLAG_CANNOT_SET_ENABLED |
       TP_STORAGE_RESTRICTION_FLAG_CANNOT_SET_PARAMETERS);
@@ -494,8 +573,45 @@ test_storage (Test *test,
 
   /* request the StorageSpecificProperties hash */
   tp_account_get_storage_specific_information_async (test->account,
-      get_storage_specific_info_cb, test);
-  g_main_loop_run (test->mainloop);
+      tp_tests_result_ready_cb, &test->result);
+  tp_tests_run_until_result (&test->result);
+
+  info = tp_account_get_storage_specific_information_finish (
+      test->account, test->result, &error);
+  g_assert_no_error (error);
+
+  g_assert_cmpuint (g_hash_table_size (info), ==, 3);
+
+  g_assert_cmpint (tp_asv_get_int32 (info, "one", NULL), ==, 1);
+  g_assert_cmpuint (tp_asv_get_uint32 (info, "two", NULL), ==, 2);
+  g_assert_cmpstr (tp_asv_get_string (info, "marco"), ==, "polo");
+
+  tp_clear_object (&test->result);
+
+  /* the same, but with 100% more GVariant */
+  tp_account_dup_storage_specific_information_vardict_async (test->account,
+      tp_tests_result_ready_cb, &test->result);
+  tp_tests_run_until_result (&test->result);
+
+  gvariant = tp_account_dup_storage_specific_information_vardict_finish (
+      test->account, test->result, &error);
+  g_assert_no_error (error);
+
+  g_assert_cmpstr (g_variant_get_type_string (gvariant), ==, "a{sv}");
+  found = g_variant_lookup (gvariant, "one", "i", &i);
+  g_assert (found);
+  g_assert_cmpint (i, ==, 1);
+  found = g_variant_lookup (gvariant, "two", "u", &u);
+  g_assert (found);
+  g_assert_cmpint (u, ==, 2);
+  found = g_variant_lookup (gvariant, "marco", "&s", &s);
+  g_assert (found);
+  g_assert_cmpstr (s, ==, "polo");
+  found = g_variant_lookup (gvariant, "barisione", "&s", &s);
+  g_assert (!found);
+
+  g_variant_unref (gvariant);
+  tp_clear_object (&test->result);
 }
 
 static void
@@ -544,6 +660,33 @@ test_addressing (Test *test,
 
 }
 
+static void
+test_avatar (Test *test,
+    gconstpointer mode)
+{
+  const GArray *blob;
+  GError *error = NULL;
+
+  test->account = tp_account_new (test->dbus, ACCOUNT_PATH, NULL);
+  g_assert (test->account != NULL);
+
+  tp_proxy_prepare_async (test->account, NULL, account_prepare_cb, test);
+  g_main_loop_run (test->mainloop);
+
+  tp_account_get_avatar_async (test->account,
+      tp_tests_result_ready_cb, &test->result);
+  tp_tests_run_until_result (&test->result);
+
+  blob = tp_account_get_avatar_finish (
+      test->account, test->result, &error);
+  g_assert_no_error (error);
+
+  g_assert_cmpuint (blob->len, ==, 4);
+  g_assert_cmpstr (((char *) blob->data), ==, ":-)");
+
+  tp_clear_object (&test->result);
+}
+
 static void
 test_connection (Test *test,
     gconstpointer data G_GNUC_UNUSED)
@@ -552,6 +695,10 @@ test_connection (Test *test,
   GHashTable *change = tp_asv_new (NULL, NULL);
   TpConnection *conn;
   const GHashTable *details;
+  GVariant *details_v;
+  gboolean found;
+  gchar *s;
+  guint32 u;
 
   test->account = tp_account_new (test->dbus, ACCOUNT_PATH, NULL);
   g_assert (test->account != NULL);
@@ -694,6 +841,20 @@ test_connection (Test *test,
   g_assert_cmpuint (tp_asv_get_uint32 (details, "bits-of-entropy", NULL), ==,
       15);
 
+  s = tp_account_dup_detailed_error_vardict (test->account, &details_v);
+  g_assert_cmpstr (s, ==, "org.debian.packages.OpenSSL.NotRandomEnough");
+  g_free (s);
+  g_assert_cmpuint (g_variant_n_children (details_v), >=, 2);
+  g_assert_cmpstr (g_variant_get_type_string (details_v), ==, "a{sv}");
+  found = g_variant_lookup (details_v, "debug-message", "s", &s);
+  g_assert (found);
+  g_assert_cmpstr (s, ==, "shiiiiii-");
+  g_free (s);
+  found = g_variant_lookup (details_v, "bits-of-entropy", "u", &u);
+  g_assert (found);
+  g_assert_cmpint (u, ==, 15);
+  g_variant_unref (details_v);
+
   /* staple on a Connection (this is intended for use in e.g. observers,
    * if they're told about a Connection that the Account hasn't told them
    * about yet) */
@@ -759,6 +920,11 @@ main (int argc,
   g_test_add ("/account/setters", Test, NULL, setup_service, test_setters,
       teardown_service);
 
+  g_test_add ("/account/reconnect", Test, NULL, setup_service, test_reconnect,
+      teardown_service);
+  g_test_add ("/account/reconnect", Test, "vardict", setup_service,
+      test_reconnect, teardown_service);
+
   g_test_add ("/account/prepare/success", Test, NULL, setup_service,
               test_prepare_success, teardown_service);
 
@@ -770,6 +936,9 @@ main (int argc,
   g_test_add ("/account/storage", Test, "later", setup_service, test_storage,
       teardown_service);
 
+  g_test_add ("/account/avatar", Test, NULL, setup_service, test_avatar,
+      teardown_service);
+
   g_test_add ("/account/addressing", Test, "first", setup_service,
       test_addressing, teardown_service);
   g_test_add ("/account/addressing", Test, "later", setup_service,
