@@ -8,6 +8,8 @@
  * notice and this notice are preserved.
  */
 
+#include "config.h"
+
 #include <telepathy-glib/connection.h>
 #include <telepathy-glib/dbus.h>
 #include <telepathy-glib/debug.h>
@@ -108,9 +110,7 @@ main (int argc,
   MYASSERT (tp_connection_run_until_ready (conn, TRUE, &error, NULL), "");
   g_assert_no_error (error);
 
-  MYASSERT (tp_cli_connection_run_disconnect (conn, -1, &error, NULL), "");
-  g_assert_no_error (error);
-
+  tp_tests_connection_assert_disconnect_succeeds (conn);
   g_object_unref (conn);
 
   service_conn_as_base = NULL;
