@@ -10,6 +10,8 @@
  * notice and this notice are preserved.
  */
 
+#include "config.h"
+
 #include <telepathy-glib/connection.h>
 #include <telepathy-glib/contact.h>
 #include <telepathy-glib/dbus.h>
@@ -1217,16 +1219,8 @@ static void
 teardown (Fixture *f,
     gconstpointer unused G_GNUC_UNUSED)
 {
-  GError *error = NULL;
-  gboolean ok;
-
   if (f->legacy_client_conn != NULL)
-    {
-      ok = tp_cli_connection_run_disconnect (f->legacy_client_conn, -1,
-            &error, NULL);
-      g_assert_no_error (error);
-      g_assert (ok);
-    }
+    tp_tests_connection_assert_disconnect_succeeds (f->legacy_client_conn);
 
   f->service_repo = NULL;
   tp_clear_object (&f->legacy_client_conn);
