@@ -8,6 +8,8 @@
  * notice and this notice are preserved.
  */
 
+#include "config.h"
+
 #include <glib.h>
 #include <string.h>
 
@@ -256,9 +258,7 @@ teardown (Test *test,
   tp_clear_object (&test->chan_service);
   tp_clear_object (&test->cm_stream);
 
-  tp_cli_connection_run_disconnect (test->connection, -1, &test->error, NULL);
-  g_assert_no_error (test->error);
-
+  tp_tests_connection_assert_disconnect_succeeds (test->connection);
   g_object_unref (test->connection);
   g_object_unref (test->base_connection);
 
