@@ -7,6 +7,8 @@
  * notice and this notice are preserved.
  */
 
+#include "config.h"
+
 #include <telepathy-glib/simple-handler.h>
 #include <telepathy-glib/client.h>
 #include <telepathy-glib/debug.h>
@@ -151,9 +153,7 @@ teardown (Test *test,
   g_object_unref (test->text_chan_service);
   g_object_unref (test->text_chan);
 
-  tp_cli_connection_run_disconnect (test->connection, -1, &test->error, NULL);
-  g_assert_no_error (test->error);
-
+  tp_tests_connection_assert_disconnect_succeeds (test->connection);
   g_object_unref (test->connection);
   g_object_unref (test->base_connection);
 }
