@@ -11,6 +11,8 @@
  * notice and this notice are preserved.
  */
 
+#include "config.h"
+
 #include "echo-im-manager.h"
 
 #include <dbus/dbus-glib.h>
@@ -146,8 +148,7 @@ tp_tests_echo_im_manager_class_init (TpTestsEchoImManagerClass *klass)
   param_spec = g_param_spec_object ("connection", "Connection object",
       "The connection that owns this channel manager",
       TP_TYPE_BASE_CONNECTION,
-      G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE |
-      G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB);
+      G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
   g_object_class_install_property (object_class, PROP_CONNECTION, param_spec);
 
   g_type_class_add_private (klass, sizeof (TpTestsEchoImManagerPrivate));
